==> apeman-app-sign-4.0.4.tgz: package/lib/doing/do_update_sign.js <==
/**
 * @function doUpdateSign
 */
'use strict'

const co = require('co')
const doUpdate = require('apeman-app-rest/lib/doing/do_update')
const modelOne = require('apeman-app-rest/lib/modeling/model_one')

/** @lends doUpdateSign */
function doUpdateSign (config) {
  let digest = config.digest

  let _dataBeforeUpdate = (data, instance) => co(function * () {
    let attributes = data.attributes

    // Ignore given hash and salt
    delete attributes.hash
    delete attributes.hashSalt

    attributes = Object.assign(attributes, {
      signmodAt: new Date()
    })
    let password = attributes.password
    if (password) {
      attributes.hash = yield digest(password, instance.hashSalt)
    }
    delete attributes.password
    return Object.assign(data, {
      attributes
    })
  })

  let _dataAfterUpdate = (data, instance) => co(function * () {
    let attributes = data.attributes
    delete attributes.hash
    delete attributes.hashSalt
    return Object.assign(data, {
      attributes
    })
  })

  function updateSign (UserSign, context) {
    let one = modelOne(UserSign, context.transaction)
    return co(function * () {
      if (context.data) {
        let instance = yield one(context.data.id)
        context.data = yield _dataBeforeUpdate(context.data, instance)
      }
      let updated = yield doUpdate(UserSign, context)
      if (updated.data) {
        let instance = yield one(updated.data.id)
        updated.data = yield _dataAfterUpdate(updated.data, instance)
      }
      return updated
    })
  }

  Object.assign(updateSign, {
    bulk (UserSign, context) {
      let one = modelOne(UserSign, context.transaction)
      return co(function * () {
        if (context.data) {
          let data = [].concat(context.data)
          let instances = yield data.map((data) => one(data.id))
          context.data = yield data.map((data, i) => _dataBeforeUpdate(data, instances[ i ]))
        }
        let updated = yield doUpdate.bulk(UserSign, context)
        if (updated.data) {
          let data = [].concat(updated.data)
          let instances = yield data.map((data) => one(data.id))
          updated.data = yield data.map((data, i) => _dataAfterUpdate(data, instances[ i ]))
        }
        return updated
      })
    }
  })
  return updateSign
}

module.exports = doUpdateSign

==> apeman-app-sign-5.0.1.tgz: package/lib/doing/do_update_sign.js <==
/**
 * @function doUpdateSign
 */
'use strict'

const co = require('co')
const doUpdate = require('apeman-app-rest/lib/doing/do_update')
const apemanmodel = require('apemanmodel')

/** @lends doUpdateSign */
function doUpdateSign (config) {
  let digest = config.digest

  let _dataBeforeUpdate = (data, instance) => co(function * () {
    let attributes = data.attributes

    // Ignore given hash and salt
    delete attributes.hash
    delete attributes.hashSalt

    attributes = Object.assign(attributes, {
      signmodAt: new Date()
    })
    let password = attributes.password
    if (password) {
      attributes.hash = yield digest(password, instance.hashSalt)
    }
    delete attributes.password
    return Object.assign(data, {
      attributes
    })
  })

  let _dataAfterUpdate = (data, instance) => co(function * () {
    let attributes = data.attributes
    delete attributes.hash
    delete attributes.hashSalt
    return Object.assign(data, {
      attributes
    })
  })

  function updateSign (UserSign, context) {
    let one = apemanmodel.defineOne(UserSign, context.transaction)
    return co(function * () {
      if (context.data) {
        let instance = yield one(context.data.id)
        context.data = yield _dataBeforeUpdate(context.data, instance)
      }
      let updated = yield doUpdate(UserSign, context)
      if (updated.data) {
        let instance = yield one(updated.data.id)
        updated.data = yield _dataAfterUpdate(updated.data, instance)
      }
      return updated
    })
  }

  Object.assign(updateSign, {
    bulk (UserSign, context) {
      let one = apemanmodel.defineOne(UserSign, context.transaction)
      return co(function * () {
        if (context.data) {
          let data = [].concat(context.data)
          let instances = yield data.map((data) => one(data.id))
          context.data = yield data.map((data, i) => _dataBeforeUpdate(data, instances[ i ]))
        }
        let updated = yield doUpdate.bulk(UserSign, context)
        if (updated.data) {
          let data = [].concat(updated.data)
          let instances = yield data.map((data) => one(data.id))
          updated.data = yield data.map((data, i) => _dataAfterUpdate(data, instances[ i ]))
        }
        return updated
      })
    }
  })
  return updateSign
}

module.exports = doUpdateSign
